Module v1

Module v1 

Structs

Asset
AssetMeta
AssetType
AvatarResponse
AvatarScales
BodyColors
Emote
Outfit
OutfitDetails
OutfitsResponse
UniverseAvatarSettings

Enums

AvatarType
MorphAvatarType

Constants

URL

Functions

avatar_set_body_colors
Sets the authenticated user’s body colors.
avatar_set_scales
Sets the authenticated user’s body scales.
avatar_set_type
Sets the authenticated user’s player avatar type (e.g. R6 or R15).
avatar_set_wearing_assets
Sets the avatar’s current assets to the list - Flagged as obsolete, does not support layered clothing meta params.
outfit_details
Gets details about the contents of an outfit.
remove_outfit
Deletes the outfit.
universe_avatar_settings
The server will call this on game server start to request general information about the universe. This is version 1.1, which returns an entry from the UniverseAvatarType enum. During mixed mode this may return unreliable results
user_avatar
Returns details about a specified user’s avatar
user_currently_wearing
Gets a list of asset ids that the user is currently wearing
user_outfits
Deprecated, use v2. Gets a list of outfits for the specified user.

Type Aliases

ColorId