Module data

Module data 

Constants

URL

Functions

upload
id can be set to None, or Some(0) to upload a new asset, using an existing id will overwrite the old asset on success RETURNS the new asset id