upload

Function upload 

pub async fn upload(
    client: &mut Client,
    id: Option<u64>,
    name: &str,
    description: &str,
    asset_type: AssetTypeId,
    group_id: Option<u64>,
    genre: u8,
    is_public: bool,
    allow_comments: bool,
    bytes: &[u8],
) -> Result<u64, Error>
id can be set to None, or Some(0) to upload a new asset, using an existing id will overwrite the old asset on success RETURNS the new asset id