Module v1

Module v1 

Structs

ContentModerationPermissions
EconomyPermissions
ForumsPermissions
GroupInformation
GroupRole
GroupShout
GroupUser
GroupUsers
ManagementPermissions
Membership
MembershipPermissions
NameHistory
NotificationPreference
OpenCloudPermissions
Permissions
PostPermissions
RolePermissions
UserRole
WallPost
WallPosts

Constants

URL

Functions

information
join
membership
Gets group membership information in the context of the authenticated user
name_history
Gets the Group’s name change history
pending_join_requests
Gets groups that the authenticated user has requested to join
remove
remove_join_request
role_permissions
Gets all permissions for each role
roles
roleset_permissions
Gets the permissions for a group’s roleset. The authorized user must either be the group owner or the roleset being requested, except for guest roles, which can be viewed by all (members and guests).
user_roles
users
wall_posts
Gets a list of group wall posts