Module v1

Module v1 

Structs

ThumbnailBatchRequest
ThumbnailResponse
ThumbnailResponseFromBatch
ThumbnailSizeIter
An iterator over the variants of ThumbnailSize

Enums

ReturnPolicy
ThumbnailFormat
ThumbnailRequestType
ThumbnailSize
ThumbnailState
ThumbnailVersion

Constants

URL

Functions

asset_3d
Returns a 3D thumbnail of an asset.
assets
Returns thumbnail URLs for a list of asset ids.
avatar_3d
Returns a 3D avatar thumbnail for a user id.
avatar_busts
Returns avatar bust thumbnail URLs for a list of user ids.
avatar_headshots
Returns avatar headshot thumbnail URLs for a list of user ids.
avatars
Returns avatar thumbnail URLs for a list of user ids.
badge_icons
Returns thumbnail URLs for a list of badge ids.
batch
Returns batch thumbnail results for multiple requests of varying types and sizes.
bundles
Returns thumbnail URLs for a list of bundle ids.
developer_products
Returns thumbnail URLs for a list of developer product ids.
game_icons
Returns game icon URLs for a list of universe ids.
gamepasses
Returns thumbnail URLs for a list of game pass ids.
games
Returns thumbnail URLs for a list of universe ids.
group_icons
Returns thumbnail URLs for a list of group ids.
outfit_3d
Returns a 3D outfit thumbnail for an outfit id.
outfits
Returns outfit thumbnail URLs for a list of user outfit ids.
place_icons
Returns place icon URLs for a list of place ids.
universe_thumbnails
Fetches game thumbnail URLs for a list of universes’ thumbnail ids. Ids that do not correspond to a valid thumbnail will be filtered out.