Structs
- Asset
- Asset
Meta - Asset
Type - Avatar
Response - Avatar
Scales - Body
Colors - Emote
- Outfit
- Outfit
Details - Outfits
Response - Universe
Avatar Settings
Enums
Constants
Functions
- avatar_
set_ body_ colors - Sets the authenticated user’s body colors.
- avatar_
set_ scales - Sets the authenticated user’s body scales.
- avatar_
set_ type - Sets the authenticated user’s player avatar type (e.g. R6 or R15).
- avatar_
set_ wearing_ assets - Sets the avatar’s current assets to the list - Flagged as obsolete, does not support layered clothing meta params.
- outfit_
details - Gets details about the contents of an outfit.
- remove_
outfit - Deletes the outfit.
- universe_
avatar_ settings - The server will call this on game server start to request general information about the universe. This is version 1.1, which returns an entry from the UniverseAvatarType enum. During mixed mode this may return unreliable results
- user_
avatar - Returns details about a specified user’s avatar
- user_
currently_ wearing - Gets a list of asset ids that the user is currently wearing
- user_
outfits - Deprecated, use v2. Gets a list of outfits for the specified user.