Structs
- Thumbnail
Batch Request - Thumbnail
Response - Thumbnail
Response From Batch - Thumbnail
Size Iter - An iterator over the variants of ThumbnailSize
Enums
Constants
Functions
- asset_
3d - Returns a 3D thumbnail of an asset.
- assets
- Returns thumbnail URLs for a list of asset ids.
- avatar_
3d - Returns a 3D avatar thumbnail for a user id.
- avatar_
busts - Returns avatar bust thumbnail URLs for a list of user ids.
- avatar_
headshots - Returns avatar headshot thumbnail URLs for a list of user ids.
- avatars
- Returns avatar thumbnail URLs for a list of user ids.
- badge_
icons - Returns thumbnail URLs for a list of badge ids.
- batch
- Returns batch thumbnail results for multiple requests of varying types and sizes.
- bundles
- Returns thumbnail URLs for a list of bundle ids.
- developer_
products - Returns thumbnail URLs for a list of developer product ids.
- game_
icons - Returns game icon URLs for a list of universe ids.
- gamepasses
- Returns thumbnail URLs for a list of game pass ids.
- games
- Returns thumbnail URLs for a list of universe ids.
- group_
icons - Returns thumbnail URLs for a list of group ids.
- outfit_
3d - Returns a 3D outfit thumbnail for an outfit id.
- outfits
- Returns outfit thumbnail URLs for a list of user outfit ids.
- place_
icons - Returns place icon URLs for a list of place ids.
- universe_
thumbnails - Fetches game thumbnail URLs for a list of universes’ thumbnail ids. Ids that do not correspond to a valid thumbnail will be filtered out.